@@ -11,6 +11,8 @@ from rest_framework.exceptions import ErrorDetail
 from rest_framework.pagination import PageNumberPagination
 from rest_framework.response import Response
 
+from django.conf import settings
+
 from audoma.drf.generics import GenericAPIView
 
 
@@ -73,15 +75,24 @@ class GenericViewSet(viewsets.ViewSetMixin, GenericAPIView):
     pagination_class = AudomaPagination
 
     def _parse_single_response_data_item(self, item):
-        if isinstance(item, str):
-            return item
-        elif isinstance(item, ErrorDetail):
+        if isinstance(item, ErrorDetail):
             return str(item)
+        elif isinstance(item, str):
+            return item
         elif isinstance(item, list) or isinstance(item, dict):
             return self._parse_response_data(item)
         else:
             raise UnknownExceptionContentTypeError
 
+    def _simplify_validation_errors(self, parsed_data):
+        if (
+            isinstance(parsed_data, list)
+            and len(parsed_data) == 1
+            and all(isinstance(d, str) for d in parsed_data)
+        ):
+            parsed_data = "".join(parsed_data)
+        return parsed_data
+
     def _parse_response_data(
         self, response_data: Union[List[Any], Dict[Any, Any]]
     ) -> Union[List[Any], Dict[Any, Any]]:
@@ -95,6 +106,8 @@ class GenericViewSet(viewsets.ViewSetMixin, GenericAPIView):
                 parsed_data.append((key, item))
             parsed_data = dict(parsed_data)
 
+        if getattr(settings, "AUDOMA_SIMPLIFY_VALIDATION_ERRORS", False):
+            parsed_data = self._simplify_validation_errors(parsed_data)
         return parsed_data
 
     def handle_exception(self, exc: Exception) -> Response:
@@ -107,6 +120,13 @@ class GenericViewSet(viewsets.ViewSetMixin, GenericAPIView):
                             response.data[k] = self._parse_response_data(
                                 response.data[k]
                             )
+                        elif getattr(
+                            settings, "AUDOMA_SIMPLIFY_VALIDATION_ERRORS", False
+                        ):
+                            response.data[k] = self._simplify_validation_errors(
+                                response.data[k]
+                            )
+
                 response.data = {"errors": response.data}
         elif isinstance(response.data, list):
             response.data = {"errors": response.data}
