@@ -576,6 +576,7 @@ class AudomaViewsTestCase(TestCase):
             format="json",
         )
         self.assertEqual(response.status_code, 201)
+        self.assertTrue(response.has_header("CustomHeader"))
         response_content = json.loads(response.content)
         self.assertEqual(self.data["char_field"], response_content["char_field"])
         self.assertEqual(self.data["mac_adress"], response_content["mac_adress"])
@@ -588,6 +589,7 @@ class AudomaViewsTestCase(TestCase):
             format="json",
         )
         self.assertEqual(response.status_code, 202)
+        self.assertTrue(response.has_header("CustomHeader"))
         response_content = json.loads(response.content)
         self.assertEqual(response_content["rate"], 0)
 
@@ -616,6 +618,15 @@ class AudomaViewsTestCase(TestCase):
         self.assertEqual(response.status_code, 400)
         self.assertEqual(content["errors"]["rate"], ["This field is required."])
 
+    @override_settings(AUDOMA_SIMPLIFY_VALIDATION_ERRORS=True)
+    def test_rate_create_action_post_failure_join_errors(self):
+        response = self.client.post(
+            reverse("permissionless-model-examples-rate-create-action")
+        )
+        content = json.loads(response.content)
+        self.assertEqual(response.status_code, 400)
+        self.assertEqual(content["errors"]["rate"], "This field is required.")
+
     def test_specific_rate_get_success(self):
         response = self.client.get(
             reverse("permissionless-model-examples-specific-rate", kwargs={"pk": 1})
